import QtQuick 2.9
import QtQuick.Controls 2.12
import QtQuick.Layouts 1.3
import org.kde.kirigami 2.16 as Kirigami

import MaliitKeyboard 2.0

import "keys/"

Item {
    id: root

    property bool isSelectionMode: false

    onVisibleChanged: {
        if (root.visible) {
            root.isSelectionMode = false;
            KlipperModel.sync();
        }
    }

    anchors {
        fill: parent
        topMargin: 0
        leftMargin: Device.gu(1)
        rightMargin: Device.gu(1)
        bottomMargin: Device.gu(1)
    }

    SystemPalette {
        id: activePalette
        colorGroup: SystemPalette.Active
    }

    ColumnLayout {
        anchors.fill: parent

        Page {
            Layout.alignment: Qt.AlignTop
            Layout.fillWidth: true
            contentItem: RowLayout {
                Button {
                    icon.name: "go-previous-symbolic"

                    onClicked: {
                        fullScreenItem.exitKlipperPage();
                    }
                }

                Label {
                    text: Gettext.qsTr("Clipboard")
                    Layout.fillWidth: true
                }

                Button {
                    icon.name: "edit-delete-symbolic"
                    visible: root.isSelectionMode
                    onClicked: {
                        root.isSelectionMode = false;
                        KlipperModel.removeSelectedValues();
                    }
                }

                Button {
                    icon.name: "view-refresh-symbolic"
                    onClicked: {
                        root.isSelectionMode = false;
                        KlipperModel.sync();
                    }
                }

                Button {
                    icon.name: "document-save-symbolic"
                    onClicked: {
                        root.isSelectionMode = false;
                        KlipperModel.save();
                    }
                }

                Button {
                    icon.name: "edit-symbolic"
                    onClicked: {
                        root.isSelectionMode = !root.isSelectionMode;
                    }
                }

                Switch {
                    text: Gettext.qsTr("Enable")
                    checked: KlipperModel.klipperStatus
                    onCheckedChanged: KlipperModel.klipperStatus = checked
                }
            }
        }

        Flickable {
            id: flickable
            Layout.fillHeight: true
            Layout.fillWidth: true
            contentWidth: contentItem.childrenRect.width
            contentHeight: contentItem.childrenRect.height

            clip: true

            Flow {
                spacing: 6
                width: flickable.width

                Repeater {
                    model: KlipperModel
                    delegate: textDelegate
                }
            }
        }
    }

    Component {
        id: textDelegate
        Button {
            id: button
            text: model.text

            padding: 10
            checkable: root.isSelectionMode
            icon.name: {
                if (root.isSelectionMode)
                    return checked ? "object-select-symbolic" : "empty"
                return ""
            }

            RowLayout {
                id: rowLayout
                visible: false

                Kirigami.Icon {
                    visible: root.isSelectionMode
                    Layout.preferredWidth: button.icon.width
                    Layout.preferredHeight: button.icon.height
                    source: button.checked ? "object-select-symbolic" : "empty"
                }

                ColumnLayout {
                    spacing: 0
                    Image {
                        id: image
                        readonly property double imageWidth: root.height / 3 * 2
                        readonly property double imageHeight: root.height / 3
                        source: model.text
                        onStatusChanged: {
                            if (status == Image.Ready) {
                                button.contentItem = rowLayout;
                                rowLayout.visible = true;
                                button.topPadding = 5;
                                button.bottomPadding = 5;
                            }
                        }

                        Layout.alignment: Qt.AlignHCenter
                        Layout.maximumWidth: imageWidth
                        Layout.maximumHeight: imageHeight
                        sourceSize: Qt.size(imageWidth, imageHeight)
                        fillMode: Image.PreserveAspectFit
                    }

                    Label {
                        id: text
                        text: model.text
                        clip: true
                        Layout.alignment: Qt.AlignHCenter | Qt.AlignBottom
                        Layout.maximumWidth: image.imageWidth
                        Layout.maximumHeight: image.imageHeight
                    }
                }
            }

            onClicked: {
                if (!root.isSelectionMode) {
                    KlipperModel.setClipboardContents(model.text);
                    fullScreenItem.paste();
                }
            }

            onCheckedChanged: {
                model.selected = checked
            }

            onPressAndHold: {
                root.isSelectionMode = true
                checked = true
            }

            background: Rectangle {
                id: delegateBackground
                radius: button.height / 10
                color: button.down ? activePalette.mid : activePalette.button
            }
        }
    }
}
